@@ -1,6 +1,5 @@
-context("flextable")
-
-library(modelsummary)
+# flextable is not installed on CRAN's M1 machine
+skip_if_not_installed("flextable")
 
 models <- list()
 models[['OLS 1']] <- lm(hp ~ mpg + wt, mtcars)
@@ -10,7 +9,6 @@ models[['Logit 1']] <- glm(vs ~ hp + drat, mtcars, family = binomial())
 models[['Logit 2']] <- glm(am ~ hp + disp, mtcars, family = binomial())
 
 test_that("no error with caption and notes", {
-
   expect_error(modelsummary(models, "flextable", title = "test title",
                             notes = "test note", stars = TRUE), NA)
 
